<?php 




$lan = array(
  "Export" => "Exportar",
  "ExportOnList" => "Exportar PHPList em %1 de %2 a %3 (%4).csv",
  "ExportFromval" => "Exportar PHPList de %1 a %2 (%3).csv",
  "ListMembership" => "Lista de Membros",
  "ExportOn" => "<h4>Exportar usu&aacute;rios em %s</h4>",
  "DateFrom" => "a partir de:",
  "DateTo" => "at&eacute;:",
  "DateToUsed" => "Que data deve ser usada:",
  "WhenSignedUp" => "Quando eles entraram",
  "WhenRecordChanged" => "Quando o registro foi alterado",
  'When they subscribed to' => 'Inscrito em ',
  "SelectColToIn" => "Selecionar as colunas para exporta&ccedil;&atilde;o",
);
?>
